@@ -61,7 +61,7 @@ class LogDataset(ABC):
         self.load_event_templates()
         self.assign_event_id_to_logs()
 
-    def create_graphs(self, window_type, window_size, window_slide, test_id, include_last=True,
+    def create_graphs(self, window_type, window_size, window_slide, test_id=None, include_last=True,
                       include_all_event_ids=False) \
             -> List[Mapping[str, Union[str, Mapping[str, Mapping[str, float]]]]]:
         """
@@ -110,7 +110,7 @@ class LogDataset(ABC):
     def create_networkx_graphs(self, window_type,
                                window_size,
                                window_slide,
-                               test_id,
+                               test_id=None,
                                include_last=True,
                                include_all_event_ids=False,
                                include_positional_embeddings=False) -> List[networkx.Graph]:
@@ -263,65 +263,104 @@ class BGLDataset(LogDataset):
 
             print("BGL logs parsing is complete!")
 
-        self.logs = pd.read_csv(output_dir + 'processed_logs.log_structured.csv')
-        self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
-        self.logs['Time'] = pd.to_datetime(self.logs['Time'], format='%Y-%m-%d %H:%M:%S.%f')
-        self.logs.sort_values(['Time'])
+            print("Starting to clean up the logs!")
+            self.logs = pd.read_csv(output_dir + 'processed_logs.log_structured.csv')
+            self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
+            self.logs['Time'] = pd.to_datetime(self.logs['Time'], format='%Y-%m-%d %H:%M:%S.%f')
+            self.logs.sort_values(['Time'])
 
-        anomalous_event_ids_dict = {k: 0 for k in list(self.logs[self.logs['Label'] != '-']['EventId'].unique())}
+            anomalous_event_ids_dict = {k: 0 for k in list(self.logs[self.logs['Label'] != '-']['EventId'].unique())}
 
-        normal_event_ids = list(self.logs[self.logs['Label'] == '-']['EventId'].unique())
+            normal_event_ids = list(self.logs[self.logs['Label'] == '-']['EventId'].unique())
 
-        mutual_event_ids = []
-        for event_id in normal_event_ids:
-            if event_id in anomalous_event_ids_dict.keys():
-                mutual_event_ids.append(event_id)
+            mutual_event_ids = []
+            for event_id in normal_event_ids:
+                if event_id in anomalous_event_ids_dict.keys():
+                    mutual_event_ids.append(event_id)
 
-        for event_id in mutual_event_ids:
-            tmp_df = self.logs[self.logs['EventId'] == event_id]
-            total_count = len(tmp_df)
-            normal_count = len(tmp_df[tmp_df['Label'] == '-'])
-            anomalous_count = total_count - normal_count
-            anomalous_percentage = anomalous_count * 100.0 / total_count
-            normal_percentage = normal_count * 100.0 / total_count
-            diff = abs(anomalous_percentage - normal_percentage)
+            for event_id in mutual_event_ids:
+                tmp_df = self.logs[self.logs['EventId'] == event_id]
+                total_count = len(tmp_df)
+                normal_count = len(tmp_df[tmp_df['Label'] == '-'])
+                anomalous_count = total_count - normal_count
+                anomalous_percentage = anomalous_count * 100.0 / total_count
+                normal_percentage = normal_count * 100.0 / total_count
+                diff = abs(anomalous_percentage - normal_percentage)
 
-            if normal_percentage > 90.0:  # threshold
-                del anomalous_event_ids_dict[event_id]
-                self.logs = self.logs.drop(
-                    self.logs[(self.logs['EventId'] == event_id) & (self.logs['Label'] != '-')].index)
-            elif anomalous_percentage > 90.0:
-                self.logs = self.logs.drop(
-                    self.logs[(self.logs['EventId'] == event_id) & (self.logs['Label'] == '-')].index)
-            elif diff < 30.0:  # Split the event templates into two separate templates if the difference is less than 25%
-                self.logs['EventId'] = self.logs.apply(lambda row: split_row(row, event_id), axis=1)
-                del anomalous_event_ids_dict[event_id]
-                self.templates = self.templates.drop(self.templates[self.templates['EventId'] == event_id].index)
-                # Add the anomalous template in the anomalous templates dict
-                anomalous_event_ids_dict[f'{event_id}_a'] = 1
-                anomalous_event_ids_dict[f'{event_id}_n'] = 1
+                if normal_percentage > 90.0:  # threshold
+                    print(f"Logs with eventID {event_id} have mixed types but more than 90% normal logs. "
+                          f"Dropping the anomalous logs from this event type and removing the event id "
+                          f"from the list of anomalous event ids")
+                    del anomalous_event_ids_dict[event_id]
+                    self.logs = self.logs.drop(
+                        self.logs[(self.logs['EventId'] == event_id) & (self.logs['Label'] != '-')].index)
+                elif anomalous_percentage > 90.0:
+                    print(f"Logs with eventID {event_id} have mixed types but more than 90% anomalous logs. "
+                          f"Dropping the normal logs from this event type")
+                    self.logs = self.logs.drop(
+                        self.logs[(self.logs['EventId'] == event_id) & (self.logs['Label'] == '-')].index)
+                elif diff < 30.0:  # Split the event templates into two separate templates if the difference is less than 25%
+                    print(f"Logs with event ID {event_id} have less that 30% difference in the count of anomalous "
+                          f"and normal logs. Splitting the event to 2 events: {event_id}_n for all the normal logs and "
+                          f"{event_id}_a for all the anomalous logs.")
+                    self.logs['EventId'] = self.logs.apply(lambda row: split_row(row, event_id), axis=1)
+                    del anomalous_event_ids_dict[event_id]
+                    self.templates = self.templates.drop(self.templates[self.templates['EventId'] == event_id].index)
+                    # Add the anomalous template in the anomalous templates dict
+                    anomalous_event_ids_dict[f'{event_id}_a'] = 1
+                    anomalous_event_ids_dict[f'{event_id}_n'] = 1
 
-                self.templates = pd.concat(
-                    [self.templates,
-                     pd.DataFrame([
-                         {"EventId": f'{event_id}_a'},
-                         {"EventId": f'{event_id}_n'}
-                     ])
-                     ]
-                )
+                    self.templates = pd.concat(
+                        [self.templates,
+                         pd.DataFrame([
+                             {"EventId": f'{event_id}_a'},
+                             {"EventId": f'{event_id}_n'}
+                         ])
+                         ]
+                    )
 
-            else:  #
-                del anomalous_event_ids_dict[event_id]
-                self.logs = self.logs.drop(self.logs[self.logs['EventId'] == event_id].index)
-                self.templates = self.templates.drop(self.templates[self.templates['EventId'] == event_id].index)
+                else:  #
+                    del anomalous_event_ids_dict[event_id]
+                    self.logs = self.logs.drop(self.logs[self.logs['EventId'] == event_id].index)
+                    self.templates = self.templates.drop(self.templates[self.templates['EventId'] == event_id].index)
 
-        self.anomalous_logs = list(anomalous_event_ids_dict.keys())
+                self.anomalous_logs = list(anomalous_event_ids_dict.keys())
 
-        self.logs.to_csv(output_dir + 'processed_logs.log_structured.csv')
-        self.templates.to_csv(output_dir + 'processed_logs.log_templates.csv')
+                self.logs.to_csv(output_dir + 'processed_logs.log_structured.csv')
+                self.templates.to_csv(output_dir + 'processed_logs.log_templates.csv')
 
-        self.logs = self.logs[['Time', 'EventId']]
-        self.logs.rename(columns={'Time': 'timestamp', 'EventId': 'event_id'}, inplace=True)
+                self.logs = self.logs[['Time', 'EventId']]
+                self.logs.rename(columns={'Time': 'timestamp', 'EventId': 'event_id'}, inplace=True)
+
+        if not exists(f'{self.data_folder_path}/bgl/processed_logs.log_structured_short.csv'):
+            print(f"Short processed logs not found at f'{self.data_folder_path}/bgl/processed_logs"
+                  f".log_structured_short.csv. Will process them now! Please hold.")
+            self.logs = pd.read_csv(output_dir + 'processed_logs.log_structured.csv')
+
+            self.logs = self.logs[['Time', 'EventId', 'Label']]
+            self.logs.rename(columns={'Time': 'timestamp', 'EventId': 'event_id'}, inplace=True)
+
+            self.logs.to_csv(f'{self.data_folder_path}/bgl/processed_logs.log_structured_short.csv')
+
+            self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
+
+            self.anomalous_logs = list(self.logs[self.logs['Label'] != '-']['event_id'].unique())
+
+            self.logs = self.logs[['timestamp', 'event_id']]
+
+            print(
+                f'Saving short processed structured logs for BGL at path {self.data_folder_path}/bgl'
+                f'/processed_logs.log_structured_short.csv')
+        else:
+            print(f"The short processed file is found at {self.data_folder_path}/bgl/"
+                  f"processed_logs.log_structured_short.csv. Loading the short stuff to optimize time and memory!")
+            self.logs = pd.read_csv(f'{self.data_folder_path}/bgl/processed_logs.log_structured_short.csv')
+            # self.
+            self.anomalous_logs = list(self.logs[self.logs['Label'] != '-']['event_id'].unique())
+            self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
+            self.logs['timestamp'] = pd.to_datetime(self.logs['timestamp'])
+            self.logs = self.logs[['timestamp', 'event_id']]
+            print ("Short processed file is loaded up. Have fun.")
 
     def load_event_templates(self):
         self.templates = pd.read_csv(f'{self.data_folder_path}/bgl/processed_logs.log_templates.csv')
@@ -406,7 +445,7 @@ if __name__ == '__main__':
     dataset = BGLDataset("../../data")
     dataset.initialize_dataset()
     # Create window of 1 hour * 60 min * 60 secs * 1000 ms
-    graphs = dataset.create_graphs(window_type='tumbling', window_size=1 * 60 * 60 * 1000, window_slide=0,
+    graphs = dataset.create_graphs(window_type='tumbling', window_size=4 * 60 * 60 * 1000, window_slide=0,
                                    include_last=False, test_id=1)
     for graph in graphs:
         print(graph)
